======
Series
======

This page gives an overview of all public Series methods.

.. toctree::
   :maxdepth: 2

   aggregation
   array
   attributes
   boolean
   categories
   computation
   conversion
   descriptive
   modify_select
   miscellaneous
   strings
   struct
   timeseries
